<?php
namespace OliverThiele\OtDivider\Hooks;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use TYPO3\CMS\Backend\Utility\BackendUtility;
use TYPO3\CMS\Backend\View\PageLayoutView;
use TYPO3\CMS\Backend\View\PageLayoutViewDrawItemHookInterface;

/**
 * Contains a preview rendering for the page module of CType="ot_divider"
 */
class DividerPreviewRenderer implements PageLayoutViewDrawItemHookInterface
{

    /**
     * Preprocesses the preview rendering of a content element of type "ot_divider"
     *
     * @param \TYPO3\CMS\Backend\View\PageLayoutView $parentObject Calling parent object
     * @param bool $drawItem Whether to draw the item using the default functionality
     * @param string $headerContent Header content
     * @param string $itemContent Item content
     * @param array $row Record row of tt_content
     * @return void
     */
    public function preProcess(
        PageLayoutView &$parentObject,
        &$drawItem,
        &$headerContent,
        &$itemContent,
        array &$row
    ) {
        if ($row['CType'] === 'ot_divider') {
//            if ($row['bodytext']) {
//                $itemContent .= $parentObject->linkEditContent($parentObject->renderText($row['bodytext']),
//                        $row) . '<br />';
//            }

            if ($row['layout'] == 1) {
                $itemContent .= 'Reset';
            } elseif ($row['layout'] == 2) {
                $itemContent .= '<b>Image or Color</b><br />';

                if ($row['assets']) {
                    $itemContent .= $parentObject->linkEditContent($parentObject->getThumbCodeUnlinked($row,
                            'tt_content',
                            'assets'), $row) . '<br />';

                    $fileReferences = BackendUtility::resolveFileReferences('tt_content', 'assets', $row);

                    if (!empty($fileReferences)) {
                        $linkedContent = '';

//                    foreach ($fileReferences as $fileReference) {
//                        $linkedContent .= htmlspecialchars($fileReference->getDescription()) . '<br />';
//                    }

                        $itemContent .= $parentObject->linkEditContent($linkedContent, $row);

                        unset($linkedContent);
                    }
                }
            } elseif ($row['layout'] == 3) {
                $itemContent .= 'Full width';
            }

            $drawItem = false;
        }
    }
}
